==> antd-form-designer-1.0.3.tgz: package/gulpfile.js <==
/**
 * [gulp description]
 * @type {[type]}
 */
var gulp = require("gulp");
var gutil = require("gulp-util");
var del = require("del");
var rename = require('gulp-rename');
var less = require('gulp-less');
var autoprefixer = require('gulp-autoprefixer');
var cached = require('gulp-cached');
var remember = require('gulp-remember');
var exec = require('child_process').exec;

var webpack = require("webpack");
var WebpackDevServer = require("webpack-dev-server");

var connect = require('gulp-connect');
var rest = require('connect-rest');
// var mocks = require('./mocks');

/**
 * ----------------------------------------------------
 * source configuration
 * ----------------------------------------------------
 */

var src = {
  html: "src/html/*.html",                          // html 文件
  vendor: ["vendor/**/*", "bower_components/**/*"], // vendor 目录和 bower_components
  style: "src/style/*.less",                        // style 目录下所有 xx/index.less
  assets: "assets/**/*"                             // 图片等应用资源
};

var dist = {
  root: "dist/",
  html: "dist/",
  style: "dist/style",
  vendor: "dist/vendor",
  assets: "dist/assets"
};

var bin = {
  root: "bin/",
  html: "bin/",
  style: "bin/style",
  vendor: "bin/vendor",
  assets: "bin/assets"
};

/**
 * ----------------------------------------------------
 *  tasks
 * ----------------------------------------------------
 */

/**
 * clean build dir
 */
function clean(done) {
  del.sync(dist.root);
  done();
}

/**
 * [cleanBin description]
 * @return {[type]} [description]
 */
function cleanBin(done) {
  del.sync(bin.root);
  done();
}

/**
 * [copyVendor description]
 * @return {[type]} [description]
 */
function copyVendor() {
  return gulp.src(src.vendor)
    .pipe(gulp.dest(dist.vendor));
}

/**
 * [copyAssets description]
 * @return {[type]} [description]
 */
function copyAssets() {
  return gulp.src(src.assets)
    .pipe(gulp.dest(dist.assets));
}

/**
 * [copyDist description]
 * @return {[type]} [description]
 */
function copyDist() {
  return gulp.src(dist.root + '**/*')
    .pipe(gulp.dest(bin.root));
}


function copy2Bin() {
  var src = [
    './package.json',
    './index.js',
    './README.md'
  ]

  return gulp.src(src)
    .pipe(gulp.dest('./bin'));
}

/**
 * [html description]
 * @return {[type]} [description]
 */
function html() {
    return gulp.src(src.html)
      .pipe(gulp.dest(dist.html))
}

/**
 * [style description]
 * @param  {Function} done [description]
 * @return {[type]}        [description]
 */
function style() {
    return gulp.src(src.style)
      // .pipe(cached('style'))
      .pipe(less())
      .on('error', handleError)
      .pipe(autoprefixer({
        browsers: ['last 3 version']
      }))
      .pipe(gulp.dest(dist.style))
}

exports.style = style;

/**
 * [webpackProduction description]
 * @param  {Function} done [description]
 * @return {[type]}        [description]
 */
function webpackProduction(done) {
  var config = Object.create(webpackConfig);
  config.plugins = config.plugins.concat(
    new webpack.DefinePlugin({
      "process.env": {
        "NODE_ENV": "production"
      }
    }),
    new webpack.optimize.DedupePlugin(),
    new webpack.optimize.UglifyJsPlugin()
  );

  webpack(config, function(err, stats) {
    if(err) throw new gutil.PluginError("webpack:build", err);
    gutil.log("[webpack:production]", stats.toString({
      colors: true
    }));
    done();
  });
}


/**
 * [webpackDevelopment description]
 * @param  {Function} done [description]
 * @return {[type]}        [description]
 */

function webpackDevelopment(done) {
  var devConfig, webpackConfig = require("./webpack.config.js");

  devConfig = Object.create(webpackConfig);
  devConfig.devtool = "sourcemap";
  devConfig.debug = true;
  devConfig.file = "./webpack.config.js";

  return runWebpack(devConfig)
    .then(function() {
      done();
    }, function(err) {
      throw new gutil.PluginError("webpack:build-dev", err);
      done();
    });
}

function prepublishNpm(done) {
  exec('npm run prepublish', function(err, stdout, stderr) {
    console.log('prepublish', stdout);
    console.log(stderr);      
    done();
  });
}

/**
 * [runWebpack description]
 * @return {[type]} [description]
 */
function runWebpack(config) {
    console.log(JSON.stringify(config, null, '\t'));
    return new Promise((resolve, reject) => {
        var devCompiler = webpack(config);
        devCompiler.run(function(err, stats) {
            if (err) {
                return reject(err);
            }
            gutil.log("[webpack]", stats.toString({
                colors: true
            }));
            return resolve(stats);
        })
    })
}

/**
 * [connectServer description]
 * @return {[type]} [description]
 */
function connectServer(done) {
  connect.server({
      root: dist.root,
      port: 8080,
      livereload: true,
      middleware: function(connect, opt) {
        return [rest.rester({
          context: "/"
        })]
      }
  });
  // mocks(rest);
  done();
}

/**
 * [watch description]
 * @return {[type]} [description]
 */
function watch() {
  gulp.watch(src.html, html);
  gulp.watch(["src/**/*.js", "src/**/*.jsx"], webpackDevelopment);
  gulp.watch("src/**/*.less", style);
  gulp.watch("assets/**/*", copyAssets);
  gulp.watch("vendor/**/*", copyVendor);
  gulp.watch("dist/**/*").on('change', function(file) {
  	console.log('file changed');
    gulp.src('dist/')
      .pipe(connect.reload());
  });
}

/**
 * default task
 */
gulp.task("default", gulp.series(
  clean, 
  gulp.parallel(copyAssets, copyVendor, html, style, webpackDevelopment), 
  connectServer, 
  watch
));

/** 
 * production build task
 */
gulp.task("build", gulp.series(cleanBin, copy2Bin, prepublishNpm));

/**
 * [handleError description]
 * @param  {[type]} err [description]
 * @return {[type]}     [description]
 */
function handleError(err) {
  if (err.message) {
    console.log(err.message)
  } else {
    console.log(err)
  }
  this.emit('end')
}

/**
 * [reload description]
 * @return {[type]} [description]
 */
function reload() {
	console.log('reload page');
	connect.reload();
}

==> antd-form-designer-1.0.5.tgz: package/gulpfile.js <==
/**
 * [gulp description]
 * @type {[type]}
 */
var gulp = require("gulp");
var gutil = require("gulp-util");
var del = require("del");
var rename = require('gulp-rename');
var less = require('gulp-less');
var autoprefixer = require('gulp-autoprefixer');
var cached = require('gulp-cached');
var remember = require('gulp-remember');
var exec = require('child_process').exec;

var webpack = require("webpack");
var WebpackDevServer = require("webpack-dev-server");

var connect = require('gulp-connect');
var rest = require('connect-rest');
// var mocks = require('./mocks');

/**
 * ----------------------------------------------------
 * source configuration
 * ----------------------------------------------------
 */

var src = {
  html: "src/html/*.html",                          // html 文件
  vendor: ["vendor/**/*", "bower_components/**/*"], // vendor 目录和 bower_components
  style: "src/style/*.less",                        // style 目录下所有 xx/index.less
  assets: "assets/**/*"                             // 图片等应用资源
};

var dist = {
  root: "dist/",
  html: "dist/",
  style: "dist/style",
  vendor: "dist/vendor",
  assets: "dist/assets"
};

var bin = {
  root: "bin/",
  html: "bin/",
  style: "bin/style",
  vendor: "bin/vendor",
  assets: "bin/assets"
};

/**
 * ----------------------------------------------------
 *  tasks
 * ----------------------------------------------------
 */

/**
 * clean build dir
 */
function clean(done) {
  del.sync(dist.root);
  done();
}

/**
 * [cleanBin description]
 * @return {[type]} [description]
 */
function cleanBin(done) {
  del.sync(bin.root);
  done();
}

/**
 * [copyVendor description]
 * @return {[type]} [description]
 */
function copyVendor() {
  return gulp.src(src.vendor)
    .pipe(gulp.dest(dist.vendor));
}

/**
 * [copyAssets description]
 * @return {[type]} [description]
 */
function copyAssets() {
  return gulp.src(src.assets)
    .pipe(gulp.dest(dist.assets));
}

/**
 * [copyDist description]
 * @return {[type]} [description]
 */
function copyDist() {
  return gulp.src(dist.root + '**/*')
    .pipe(gulp.dest(bin.root));
}


function copy2Bin() {
  var src = [
    './package.json',
    './index.js',
    './README.md'
  ]

  return gulp.src(src)
    .pipe(gulp.dest('./bin'));
}

/**
 * [html description]
 * @return {[type]} [description]
 */
function html() {
    return gulp.src(src.html)
      .pipe(gulp.dest(dist.html))
}

/**
 * [style description]
 * @param  {Function} done [description]
 * @return {[type]}        [description]
 */
function style() {
    return gulp.src(src.style)
      // .pipe(cached('style'))
      .pipe(less())
      .on('error', handleError)
      .pipe(autoprefixer({
        browsers: ['last 3 version']
      }))
      .pipe(gulp.dest(dist.style))
}

exports.style = style;

/**
 * [webpackProduction description]
 * @param  {Function} done [description]
 * @return {[type]}        [description]
 */
function webpackProduction(done) {
  var config = Object.create(webpackConfig);
  config.plugins = config.plugins.concat(
    new webpack.DefinePlugin({
      "process.env": {
        "NODE_ENV": "production"
      }
    }),
    new webpack.optimize.DedupePlugin(),
    new webpack.optimize.UglifyJsPlugin()
  );

  webpack(config, function(err, stats) {
    if(err) throw new gutil.PluginError("webpack:build", err);
    gutil.log("[webpack:production]", stats.toString({
      colors: true
    }));
    done();
  });
}


/**
 * [webpackDevelopment description]
 * @param  {Function} done [description]
 * @return {[type]}        [description]
 */

function webpackDevelopment(done) {
  var devConfig, webpackConfig = require("./webpack.config.js");

  devConfig = Object.create(webpackConfig);
  devConfig.devtool = "sourcemap";
  devConfig.debug = true;
  devConfig.file = "./webpack.config.js";

  return runWebpack(devConfig)
    .then(function() {
      done();
    }, function(err) {
      throw new gutil.PluginError("webpack:build-dev", err);
      done();
    });
}

function prepublishNpm(done) {
  exec('npm run build', function(err, stdout, stderr) {
    console.log('prepublish', stdout);
    console.log(stderr);      
    done();
  });
}

/**
 * [runWebpack description]
 * @return {[type]} [description]
 */
function runWebpack(config) {
    console.log(JSON.stringify(config, null, '\t'));
    return new Promise((resolve, reject) => {
        var devCompiler = webpack(config);
        devCompiler.run(function(err, stats) {
            if (err) {
                return reject(err);
            }
            gutil.log("[webpack]", stats.toString({
                colors: true
            }));
            return resolve(stats);
        })
    })
}

/**
 * [connectServer description]
 * @return {[type]} [description]
 */
function connectServer(done) {
  connect.server({
      root: dist.root,
      port: 8080,
      livereload: true,
      middleware: function(connect, opt) {
        return [rest.rester({
          context: "/"
        })]
      }
  });
  // mocks(rest);
  done();
}

/**
 * [watch description]
 * @return {[type]} [description]
 */
function watch() {
  gulp.watch(src.html, html);
  gulp.watch(["src/**/*.js", "src/**/*.jsx"], webpackDevelopment);
  gulp.watch("src/**/*.less", style);
  gulp.watch("assets/**/*", copyAssets);
  gulp.watch("vendor/**/*", copyVendor);
  gulp.watch("dist/**/*").on('change', function(file) {
  	console.log('file changed');
    gulp.src('dist/')
      .pipe(connect.reload());
  });
}

/**
 * default task
 */
gulp.task("default", gulp.series(
  clean, 
  gulp.parallel(copyAssets, copyVendor, html, style, webpackDevelopment), 
  connectServer, 
  watch
));

/** 
 * production build task
 */
gulp.task("build", gulp.series(cleanBin, copy2Bin, prepublishNpm));

/**
 * [handleError description]
 * @param  {[type]} err [description]
 * @return {[type]}     [description]
 */
function handleError(err) {
  if (err.message) {
    console.log(err.message)
  } else {
    console.log(err)
  }
  this.emit('end')
}

/**
 * [reload description]
 * @return {[type]} [description]
 */
function reload() {
	console.log('reload page');
	connect.reload();
}
